@@ -310,136 +310,246 @@ class Region(object):
         * Screen(a, b) - takes floats a and b in the range of 0..1 and scales
             them to the screen size.
     '''
-    POINT_ARGS = frozenset([
-        'topleft', 'topright', 'bottomleft', 'bottomright', 'size',
-        'midtop', 'midbottom', 'midleft', 'midright', 'centre', 'center',
-    ])
-    X_ARGS = frozenset([
-        'left', 'right', 'x', 'width', 'w', 'centrex', 'centerx',
-    ])
-    Y_ARGS = frozenset([
-        'top', 'bottom', 'y', 'height', 'h', 'centrey', 'centery',
-    ])
+    STANDARD_ARGS = {
+        'topleft':      ('0', '0'),
+        'topright':     ('2', '0'),
+        'bottomleft':   ('0', '2'),
+        'bottomright':  ('2', '2'),
+        'size':         ('s', 's'),
+        'midtop':       ('1', '0'),
+        'midbottom':    ('1', '2'),
+        'midleft':      ('0', '1'),
+        'midright':     ('2', '1'),
+        'centre':       ('1', '1'),
+        'center':       ('1', '1'),
+        'left':         ('0', '-'),
+        'right':        ('2', '-'),
+        'x':            ('0', '-'),
+        'width':        ('s', '-'),
+        'w':            ('s', '-'),
+        'centrex':      ('1', '-'),
+        'centerx':      ('1', '-'),
+        'top':          ('-', '0'),
+        'bottom':       ('-', '2'),
+        'y':            ('-', '0'),
+        'height':       ('-', 's'),
+        'h':            ('-', 's'),
+        'centrey':      ('-', '1'),
+        'centery':      ('-', '1'),
+    }
+
     OTHER_ARGS = frozenset(['aspect'])     # The aspect ratio.
 
-    VALID_ARGS = POINT_ARGS.union(X_ARGS).union(Y_ARGS).union(OTHER_ARGS)
+    VALID_ARGS = OTHER_ARGS.union(STANDARD_ARGS.keys())
+
     def __init__(self, **kwargs):
-        for arg in kwargs:
-            if arg not in self.VALID_ARGS:
-                raise TypeError('Region() got an unexpected keyword argument '
-                        + repr(arg))
-        self._repr = 'Region(%s)' % (', '.join('%s=%r' % t for t in
-                kwargs.iteritems()))
+        self.aspect = None
+        self.aspect_dir = None
 
-        # Check for overconstraint.
-        xy_constraints = len(self.POINT_ARGS.intersection(kwargs))
-        x_constraints = len(self.X_ARGS.intersection(kwargs))
-        y_constraints = len(self.Y_ARGS.intersection(kwargs))
-        other_constraints = len(self.OTHER_ARGS.intersection(kwargs))
+        self._validateArgNames(kwargs)
+        self._setRepr(kwargs)
 
-        if x_constraints + xy_constraints > 2:
-            raise TypeError('too many constraints on horizontal placement')
-        if y_constraints + xy_constraints > 2:
-            raise TypeError('too many constraints on vertical placement')
-        if (2 * xy_constraints + x_constraints + y_constraints +
-                other_constraints) > 4:
-            raise TypeError('too many constraints on region')
-
-        # Translate to USA spelling.
-        for k in ('centrex', 'centrey', 'centre'):
-            if k in kwargs:
-                kwargs['center' + k[len('centre'):]] = kwargs.pop(k)
-
-        # Check for special constraints.
+        aspect = None
         if 'aspect' in kwargs:
-            self.aspect = aspect = float(kwargs.pop('aspect'))
-        else:
-            self.aspect = aspect = None
+            aspect = kwargs.pop('aspect')
 
-        # Mapping from constraint name to method name.
-        c2d = self.constraints_2d = []
-        c1d = self.constraints_1d = []
-
-        # Ordering of x and y arguments.
-        xargs = []
-        yargs = []
+        xConstraints = {}
+        yConstraints = {}
+        constraints_2d = []
+        constraints_1d = []
         for arg, val in kwargs.iteritems():
-            if arg in self.POINT_ARGS:
-                if arg == 'size':
-                    attr = 'getSize'
-                    xargs.insert(0, (arg, 'width', 0))
-                    yargs.insert(0, (arg, 'height', 1))
-                else:
-                    if arg == 'center':
-                        xarg, yarg = 'centerx', 'centery'
-                    elif arg == 'midleft':
-                        xarg, yarg = 'left', 'centery'
-                    elif arg == 'midright':
-                        xarg, yarg = 'right', 'centery'
-                    elif arg == 'midtop':
-                        xarg, yarg = 'centerx', 'top'
-                    elif arg == 'midbottom':
-                        xarg, yarg = 'centerx', 'bottom'
-                    elif arg.startswith('bot'):
-                        yarg, xarg = 'bottom', arg[len('bottom'):]
-                    else:
-                        yarg, xarg = arg[:3], arg[3:]
-                    attr = 'getPoint'
-                    xargs.append((arg, xarg, 0))
-                    yargs.append((arg, yarg, 1))
-                c2d.append((arg, val, attr))
-            elif arg in self.X_ARGS:
-                if arg.startswith('w'): 
-                    attr = 'getXVal'
-                    xargs.insert(0, (arg, arg, 0))
-                else:
-                    attr = 'getXPoint'
-                    xargs.append((arg, arg, 0))
-                c1d.append((arg, val, attr))
-            elif arg in self.Y_ARGS:
-                if arg.startswith('h'):
-                    attr = 'getYVal'
-                    yargs.insert(0, (arg, arg, 1))
-                else:
-                    attr = 'getYPoint'
-                    yargs.append((arg, arg, 1))
-                c1d.append((arg, val, attr))
+            xKind, yKind = self.STANDARD_ARGS[arg]
+            if xKind != '-':
+                if xKind in xConstraints:
+                    raise TypeError('specifying %s overconstrains region (x)' %
+                            (arg,))
+                xConstraints[xKind] = arg
+            if yKind != '-':
+                if yKind in yConstraints:
+                    raise TypeError('specifying %s overconstrains region (y)' %
+                            (arg,))
+                yConstraints[yKind] = arg
 
-        if aspect is not None:
-            if x_constraints + xy_constraints == 2:
-                # Underconstrained y.
-                self.aspect_dir = 'y'
-                self.pre_aspect = xargs
-                self.post_aspect = yargs
+            if xKind == '-':
+                c = constraints_1d
+                if yKind == 's':
+                    method = 'getYVal'
+                else:
+                    method = 'getYPoint'
+            elif yKind == '-':
+                c = constraints_1d
+                if xKind == 's':
+                    method = 'getXVal'
+                else:
+                    method = 'getXPoint'
             else:
-                self.aspect_dir = 'x'
-                self.pre_aspect = yargs
-                self.post_aspect = xargs
+                c = constraints_2d
+                if xKind == 's' and yKind == 's':
+                    method = 'getSize'
+                elif xKind != 's' and yKind != 's':
+                    method = 'getPoint'
+                else:
+                    raise AssertionError('definition of %r in '
+                        'Region.STANDARD_ARGS does not make sense' % (arg,))
+
+            c.append((arg, val, method))
+
+        self.constraints_2d = constraints_2d
+        self.constraints_1d = constraints_1d
+
+        xNum = len(xConstraints)
+        yNum = len(yConstraints)
+        if xNum > 2:
+            raise TypeError('Region is overconstrained horizontally')
+        if yNum > 2:
+            raise TypeError('Region is overconstrained vertically')
+        if aspect is None:
+            if xNum < 2:
+                raise TypeError('Region is underconstrained horizontally')
+            if yNum < 2:
+                raise TypeError('Region is underconstrained vertically')
+            self.constraints = [self._makeXConstraint(xConstraints),
+                    self._makeYConstraint(yConstraints)]
         else:
-            self.aspect_dir = None
-            self.pre_aspect = xargs + yargs
-            self.post_aspect = []
+            if xNum + yNum > 3:
+                raise TypeError('Region is overconstrained')
+            if xNum + yNum < 3:
+                raise TypeError('Region is underconstrained')
+            if xNum == 2:
+                self.constraints = self._makeYAspectConstraints(xConstraints,
+                        yConstraints, aspect)
+            else:
+                self.constraints = self._makeXAspectConstraints(xConstraints,
+                        yConstraints, aspect)
 
     def __repr__(self):
         return self._repr
 
+    def _setRepr(self, kwargs):
+        self._repr = 'Region(%s)' % (', '.join('%s=%r' % t for t in
+                kwargs.iteritems()))
+
+    def _validateArgNames(self, kwargs):
+        for arg in kwargs:
+            if arg not in self.VALID_ARGS:
+                raise TypeError('Region() got an unexpected keyword argument '
+                        + repr(arg))
+                
     def getRect(self, app):
+        vals = self._evaluateConstraints(app)
+        r = pygame.Rect((0, 0), (0, 0))
+        self._applyConstraints(r, vals)
+        return r
+
+    def _applyConstraints(self, r, vals):
+        for c, args in self.constraints:
+            c(r, vals, args)
+
+    def _evaluateConstraints(self, app):
         vals = {}
         for k, v, m in self.constraints_2d:
             vals[k] = getattr(v, m)(app)
         for k, v, m in self.constraints_1d:
-            vals[k] = (getattr(v, m)(app),)
-        r = pygame.Rect((0, 0), app.screenManager.size)
-        for k, a, i in self.pre_aspect:
-            setattr(r, a, vals[k][i])
-        if self.aspect_dir:
-            if self.aspect_dir == 'x':
-                r.width = r.height * self.aspect
+            result = getattr(v, m)(app)
+            vals[k] = (result, result)
+        return vals
+
+    def _standardXConstraint(self, r, vals, args):
+        p1, p2 = args
+        left, width = self._xInterval(vals[p1][0], vals[p2][0])
+        r.width = width
+        r.left = left
+
+    def _standardYConstraint(self, r, vals, args):
+        p1, p2 = args
+        top, height = self._yInterval(vals[p1][1], vals[p2][1])
+        r.height = height
+        r.top = top
+
+    def _makeXConstraint(self, xConstraints):
+        self._xInterval, args = self._getIntervalFunction(xConstraints)
+        return self._standardXConstraint, args
+        
+    def _makeYConstraint(self, yConstraints):
+        self._yInterval, args = self._getIntervalFunction(yConstraints)
+        return self._standardYConstraint, args
+
+    def _getIntervalFunction(self, constraintsDict):
+        if '0' in constraintsDict:
+            if 's' in constraintsDict:
+                intervalFunc = self._getIntervalFromInterval
+                args = constraintsDict['0'], constraintsDict['s']
+            elif '2' in constraintsDict:
+                intervalFunc = self._getIntervalFromEdges
+                args = constraintsDict['0'], constraintsDict['2']
             else:
-                r.height = r.width / self.aspect
-            for k, a, i in self.post_aspect:
-                setattr(r, a, vals[k][i])
-        return r
+                intervalFunc = self._getIntervalFromFirstHalf
+                args = constraintsDict['0'], constraintsDict['1']
+        elif '2' in constraintsDict:
+            if 's' in constraintsDict:
+                intervalFunc = self._getIntervalFromReverseInterval
+                args = constraintsDict['2'], constraintsDict['s']
+            else:
+                intervalFunc = self._getIntervalFromSecondHalf
+                args = constraintsDict['1'], constraintsDict['2']
+        else:
+            intervalFunc = self._getIntervalFromCentre
+            args = constraintsDict['1'], constraintsDict['s']
+        return intervalFunc, args
+
+    def _xAspectConstraint(self, r, vals, args):
+        aspect, attr, key = args
+        r.width = int(r.height * aspect + 0.5)
+        setattr(r, attr, vals[key][0])
+
+    def _yAspectConstraint(self, r, vals, args):
+        aspect, attr, key = args
+        r.height = int(r.width / aspect + 0.5)
+        setattr(r, attr, vals[key][1])
+
+    def _makeXAspectConstraints(self, xConstraints, yConstraints, aspect):
+        key, val = xConstraints.items().pop()
+        if key == '0':
+            attr = 'left'
+        elif key == '1':
+            attr = 'centerx'
+        elif key == '2':
+            attr = 'right'
+        else:
+            raise TypeError('Region is overconstrained')
+        return [
+            self._makeYConstraint(yConstraints),
+            (self._xAspectConstraint, (aspect, attr, val))
+        ]
+
+    def _makeYAspectConstraints(self, xConstraints, yConstraints, aspect):
+        key, val = yConstraints.items().pop()
+        if key == '0':
+            attr = 'top'
+        elif key == '1':
+            attr = 'centery'
+        elif key == '2':
+            attr = 'bottom'
+        else:
+            raise TypeError('Region is overconstrained')
+        return [
+            self._makeXConstraint(xConstraints),
+            (self._yAspectConstraint, ((aspect+0.), attr, val))
+        ]
+
+    def _getIntervalFromEdges(self, x1, x2):
+        return (x1, x2 - x1)
+    def _getIntervalFromInterval(self, x1, deltaX):
+        return (x1, deltaX)
+    def _getIntervalFromFirstHalf(self, x1, midx):
+        return (x1, 2 * (midx - x1))
+    def _getIntervalFromSecondHalf(self, midx, x2):
+        deltaX = 2 * (x2 - midx)
+        return (x2 - deltaX, deltaX)
+    def _getIntervalFromCentre(self, midx, deltaX):
+        return midx - int(deltaX / 2), deltaX
+    def _getIntervalFromReverseInterval(self, x2, deltaX):
+        return (x2 - deltaX, deltaX)
 
 class Abs(object):
     def __init__(self, *args):
