@@ -21,8 +21,9 @@ class Font(object):
     def __init__(self, name, size):
         self._name = name
         self._size = size
+        self._app = None
+        self._filename = None
 
-    # TODO: could cache resulting images        
     def render(self, app, text, antialias, colour, background=None):
         if background==None:
             return self._getFont(app).render(text, antialias, colour)
@@ -37,9 +38,13 @@ class Font(object):
 
     def getHeight(self, app):
         return self._getFont(app).get_height()
-        
+
     def _getFont(self, app):
-        filename = app.getFontFilename(self._name)
+        if app != self._app:
+            filename = self._filename = app.getFontFilename(self._name)
+            self._app = app
+        else:
+            filename = self._filename
         return fontcache.get(filename, self._size)
 
     def __repr__(self):
@@ -47,7 +52,11 @@ class Font(object):
 
 class ScaledFont(Font):
     def _getFont(self, app):
-        filename = app.getFontFilename(self._name)
+        if app != self._app:
+            filename = self._filename = app.getFontFilename(self._name)
+            self._app = app
+        else:
+            filename = self._filename
         return fontcache.get(filename,
                 int(self._size * app.screenManager.scaleFactor + 0.5))
 
