@@ -19,7 +19,7 @@ from framework import Element, CompoundElement
 from elements import TextButton, TextElement
 from trosnoth.src.gui.common import translateEvent, Location, addPositions, AttachedPoint
 from trosnoth.src.gui.screenManager.windowManager import MultiWindowException
-from trosnoth.src.gui.fonts.fontcache import get as getFont
+from trosnoth.src.gui.framework.utils import WordWrap
 from trosnoth.src.utils.event import Event
 from trosnoth.src.utils.utils import new
 import pygame
@@ -242,9 +242,19 @@ class MessageBox(DialogBox):
         if hasattr(size, 'getSize'):
             size = size.getSize(app)
         textFont = app.screenManager.fonts.labelFont
-        textPos = Location((size[0] / 2, size[1] / 3), 'midtop')
-        message = TextElement(app, message, textFont, textPos)
-        self.elements = [message]
+        lines = WordWrap(app, message, textFont, size[0])
+        y = 5
+        for text in lines:
+            textPos = Location(DialogBoxAttachedPoint(self, (0, y), 'midtop'), 'midtop')
+            self.elements.append(TextElement(app, text, textFont, textPos))
+            y += textFont.getHeight(app)
+        buttonFont = app.screenManager.fonts.captionFont
+        def getResultLambda(dialogResult):
+            return lambda sender: self.__setResultAndClose(dialogResult)
+        for x in range(0, len(buttons)):
+            dialogResult = buttons[x]
+            action = getResultLambda(dialogResult)
+            location = Location(DialogBoxAttachedPoint(self, (0, -textFont.getHeight(self.app) / 2), 'midbottom'), 'midbottom')
         buttonFont = app.screenManager.fonts.captionFont
         def getResultLambda(dialogResult):
             return lambda sender: self.__setResultAndClose(dialogResult)
