@@ -58,6 +58,7 @@ class MenuDisplay(framework.CompoundElement):
                  hidable=False, keymapping=None):
         super(MenuDisplay, self).__init__(app)
 
+        self.screenSize = app.screenManager.size
         self.location = location
         self.size = size
         self.rect = pygame.Rect(0, 0, 0, 0)
@@ -105,7 +106,23 @@ class MenuDisplay(framework.CompoundElement):
         self.image.fill(self.backColour)
         super(MenuDisplay, self).draw(self.image)
 
+    def resizeIfNeeded(self):
+        if self.app.screenManager.size == self.screenSize:
+            return
+        self.screenSize = self.app.screenManager.size
+
+        size = self.size
+        if hasattr(size, 'getSize'):
+            size = size.getSize(self.app)
+        if not self.autosize:
+            self.image = pygame.Surface(size)
+            if self.transparent:
+                self.image.set_colorkey(self.backColour)
+        self.rect.size = size
+        self.refresh(self.manager.menu)
+
     def tick(self, deltaT):
+        self.resizeIfNeeded()
         diff = self.image.get_rect().height - self.rect.height
         if diff != 0:
             sgn = diff/abs(diff)
@@ -183,14 +200,14 @@ class MenuDisplay(framework.CompoundElement):
         if self.hidable:
             stdImage = pygame.Surface((self.rect.width, itemSpacing))
             stdImage.fill(self.backColour)
-            img = self.font.render(self.app, menu.name, False, self.titleColour)
+            img = self.font.render(self.app, menu.name, True, self.titleColour)
             r = img.get_rect()
             r.center = (self.rect.width // 2, itemSpacing // 2)
             stdImage.blit(img, r)
 
             hvrImage = pygame.Surface((self.rect.width, itemSpacing))
             hvrImage.fill(self.backColour)
-            img = self.font.render(self.app, menu.name, False, self.hvrColour)
+            img = self.font.render(self.app, menu.name, True, self.hvrColour)
             hvrImage.blit(img, r)
             
             btn = elements.HoverButton(app=self.app,
@@ -244,13 +261,13 @@ class MenuDisplay(framework.CompoundElement):
                              (self.rect.width, itemHeight//2))
         else:
             # Put caption on standard canvas.    
-            img = self.font.render(self.app, item.name, False, self.stdColour)
+            img = self.font.render(self.app, item.name, True, self.stdColour)
             r = img.get_rect()
             r.midleft = (2, itemHeight // 2)
             stdImage.blit(img, r)
 
             # Put caption on hover canvas.        
-            img = self.font.render(self.app, item.name, False, self.hvrColour)
+            img = self.font.render(self.app, item.name, True, self.hvrColour)
             hvrImage.blit(img, r)
 
         if item.action is not None and self.keymapping is not None:
@@ -261,13 +278,13 @@ class MenuDisplay(framework.CompoundElement):
             else:
 
                 # Put hotkey on standard canvas.        
-                img = self.font.render(self.app, hkStr, False, self.stdColour)
+                img = self.font.render(self.app, hkStr, True, self.stdColour)
                 r = img.get_rect()
                 r.midright = (width-2, itemHeight // 2)
                 stdImage.blit(img, r)
 
                 # Put hotkey on hover canvas.        
-                img = self.font.render(self.app, hkStr, False, self.hvrColour)
+                img = self.font.render(self.app, hkStr, True, self.hvrColour)
                 hvrImage.blit(img, r)
 
         btn = elements.HoverButton(self.app, Location((x, y), 'center'),
