@@ -32,6 +32,7 @@ from trosnoth.src.utils import logging
 from trosnoth.src.model.mapLayout import LayoutDatabase
 from trosnoth.src.network.networkDefines import serverVersion
 from trosnoth.src.network.server import ServerNetHandler
+from trosnoth.src.gamerecording.gamerecorder import GameRecorder
 
 from trosnoth.src.gui import app
 
@@ -72,6 +73,8 @@ class Main(app.MultiWindowApplication):
         self.player = None
         self.layoutDatabase = LayoutDatabase(self)
 
+        self.gameRecorder = None
+
     def __str__(self):
         return 'Trosnoth Main Object'
 
@@ -130,6 +133,13 @@ class Main(app.MultiWindowApplication):
             return
         self.server = ServerNetHandler(self.layoutDatabase, self.netman,
                 halfMapWidth, mapHeight, gameDuration*60, maxPlayers)
+        
+        if recordReplay:
+            game = self.server.game
+            gameRecorder = GameRecorder(serverName, serverVersion, game.world)
+            self.gameRecorder = gameRecorder
+            game.addAgent(gameRecorder.inPlug, gameRecorder.outPlug)
+            gameRecorder.begin()
 
         # Tell the discovery protocol about it.
         if not invisibleGame:
@@ -143,6 +153,9 @@ class Main(app.MultiWindowApplication):
 
     def _serverShutdown(self):
         self.discoverer.delGame()
+        if self.gameRecorder is not None:
+            self.gameRecorder.stop()
+            self.gameRecorder = None
         self.netman.removeHandler(self.server)
         self.server = None
 
