@@ -80,7 +80,7 @@ class Obstacle(object):
         If the final position is simply the collision point, should return
         None.'''
         return None
-    
+
 class JumpableObstacle(Obstacle):
     '''Represents an obstacle that is not a wall.'''
 
@@ -134,7 +134,7 @@ class GroundObstacle(JumpableObstacle):
         This routine takes into account that if the object is travelling
         upwards, it may slide up the obstacle. Returns None if no sliding is
         going on, to indicate that the object hits the ground.'''
-        
+
         if deltaY > -0.001 or self.deltaPt[1] == 0:
             return None
 
@@ -151,18 +151,18 @@ class GroundObstacle(JumpableObstacle):
 
 class LedgeObstacle(GroundObstacle):
     drop = True
-    
+
 class RoofObstacle(Obstacle):
     def __init__(self, pt1, deltaPt):
         super(RoofObstacle, self).__init__(pt1, deltaPt)
-        
+
     def finalPosition(self, pt, deltaX, deltaY):
         '''Returns the final position of a point-sized object at the specified
         position trying to travel a displacement of [deltaX, deltaY], given
         that it collides with this obstacle.'''
         # If an object collides with a roof obstacle while falling, it still
         #  falls.
-        
+
         if deltaY > 0:
             # We collided with the roof while falling.
             # New position is where the roof is at the correct y-position.
@@ -197,7 +197,7 @@ class FillerRoofObstacle(RoofObstacle):
     '''Represents an obstacle that would be used as an obstacleEdge;
     its endpoint calculations are less precise (that being they
     don't exist), but are able to be so due to their usage.'''
-    
+
     def finalPosition(self, pt, deltaX, deltaY):
         if self.deltaPt[0] == 0:
             return pt[0], pt[1] + (deltaY/2)
@@ -218,9 +218,21 @@ class FillerRoofObstacle(RoofObstacle):
 class VerticalWall(JumpableObstacle):
     '''Represents a vertical wall that players can cling to and climb.'''
     drop = True
-    
+
     def __init__(self, pt1, deltaPt):
         assert deltaPt[0] == 0
 
         # Can drop off a vertical wall, so drop is always set to True
         super(VerticalWall, self).__init__(pt1, deltaPt)
+
+    def unstickyWallFinalPosition(self, pt, deltaX, deltaY):
+        '''Returns the final position of a point-sized object at the specified
+        position trying to travel a displacement of [deltaX, deltaY], given
+        that it collides with this obstacle.'''
+        # If an object collides with a roof obstacle while falling, it still
+        #  falls.
+
+        if deltaY == 0:
+            return None
+
+        return pt[0], pt[1] + deltaY
