@@ -15,14 +15,10 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301, USA.
 
-from trosnoth.src.model.transaction import TransactionState
-from trosnoth.src.utils.checkpoint import checkpoint
-
 class Team(object):
     '''Represents a team of the game'''
     def __init__(self, world, teamID):
         self.world = world
-        self.currentTransaction = None
         self.numOrbsOwned = 0
 
         self.captain = None
@@ -63,22 +59,10 @@ class Team(object):
     def teamReady(self):
         self.ready = True
 
-    def starCountDecreased(self):
-        transaction = self.currentTransaction
-        if (transaction is not None and transaction.state == TransactionState
-                .Open and self.world.getTeamStars(self) <
-                transaction.requiredStars):
-            checkpoint('Transaction abandoned due to player dying or leaving')
-            transaction.abandon()
-
     def playerHasLeft(self, player):
         if self.captain == player:
             self.captain = None
             self.ready = False
-        if self.currentTransaction is not None and self.currentTransaction.getNumStars(player) > 0:
-            self.currentTransaction.removeStars(player)
-            
-        self.starCountDecreased()
 
     @staticmethod
     def setOpposition(teamA, teamB):
