@@ -19,20 +19,34 @@ from trosnoth.src.utils.logging import writeException
 
 class ZoneDef(object):
     '''Stores static information about the zone.
-    
+
     Attributes:
-        adjacentZones - set of adjacent ZoneDef objects
+        adjacentZones - mapping from adjacent ZoneDef objects to collection of
+            map blocks joining the zones.
         id - the zone id (TODO: remove the need for this at this level)
         initialOwner - the team that initially owned this zone,
             represented as a number (0 for neutral, 1 or 2 for a team).
         pos - the coordinates of this zone in the map
     '''
-    def __init__(self, id, initialOwner, xCoord, yCoord):
-        self.adjacentZones = set()
+    def __init__(self, id, initialOwnerIndex, xCoord, yCoord):
+        self.adjacentZones = {}
         self.id = id
-        self.initialOwner = initialOwner
+        self.initialOwnerIndex = initialOwnerIndex
         self.pos = xCoord, yCoord
 
+    ##
+    # Return a tuple of adjacent zones, and whether each connection is open
+    def zones_AdjInfo(self):
+        ret = []
+        for adj, blocks in self.adjacentZones.iteritems():
+            ret.append((adj, not blocks[0].blocked))
+        return tuple(ret)
+
+    def __str__(self):
+        if self.id == None:
+            return 'Z---'
+        return 'Z%3d' % self.id
+
 class ZoneState(object):
     '''Represents information about a given zone and its state.
 
@@ -50,15 +64,22 @@ class ZoneState(object):
     '''
 
     def __init__(self, universe, zoneDef):
-        self.app = universe.app
         self.defn = zoneDef
         self.id = zoneDef.id
 
         universe.zoneWithDef[zoneDef] = self
-        
+
         self.universe = universe
-        self.zoneOwner = zoneDef.initialOwner
-        self.orbOwner = zoneDef.initialOwner
+        teamIndex = zoneDef.initialOwnerIndex
+        if teamIndex is None:
+            self.zoneOwner = None
+        else:
+            self.zoneOwner = universe.teams[teamIndex]
+
+            # Tell the team object that it owns one more zone
+            self.zoneOwner.orbGained()
+        self.orbOwner = self.zoneOwner
+
         self.players = set()
 
         # zone.nonPlayers are those players that do not count in zone
@@ -66,17 +87,16 @@ class ZoneState(object):
         self.nonPlayers = set()
         self.taggedThisTime = False
         self.turretedPlayer = None
-        
-    def __repr__(self):
+
+    def __str__(self):
         # Debug: uniquely identify this zone within the universe.
         if self.id == None:
             return 'Z---'
         return 'Z%3d' % self.id
-        
+
     def tag(self, player):
-        '''This method should be called by netClient when the orb in this
-        zone is tagged'''
-        
+        '''This method should be called when the orb in this zone is tagged'''
+
         # Inform the team objects
         if self.orbOwner:
             self.orbOwner.orbLost()
@@ -86,13 +106,11 @@ class ZoneState(object):
         else:
             team = None
 
-            
+
         if team == None:
             self.orbOwner = None
             self.zoneOwner = None
-            print 'Zone %s neutralised' % (self.id,)
         else:
-            print '%s tagged Zone %s' % (player.nick, self.id)
             self.orbOwner = team
             allGood = True
             for zoneDef in self.defn.adjacentZones:
@@ -109,8 +127,8 @@ class ZoneState(object):
                 self.zoneOwner = team
             else:
                 self.zoneOwner = None
-        player.incrementStars()
-    
+            player.incrementStars()
+
     def checkAgain(self):
         '''This method should be called by an adjacent friendly zone that has
         been tagged and gained. It will check to see if it now has all
@@ -145,14 +163,14 @@ class ZoneState(object):
                 if distance < tagDistance:
                     return True
         return False
-        
+
     def removePlayer(self, player):
         '''Removes a player from this zone'''
         try:
             if player.ghost:
-                self.nonPlayers.remove(player)
+                self.nonPlayers.discard(player)
             else:
-                self.players.remove(player)
+                self.players.discard(player)
         except KeyError:
             writeException()
 
@@ -167,19 +185,3 @@ class ZoneState(object):
                     self.players.add(player)
         except KeyError:
             writeException()
-
-    def getOrbImage(self):
-        if self.orbOwner:
-            return self.app.theme.sprites.orb(self.orbOwner)
-        else:
-            return self.app.theme.sprites.neutralOrb
-
-    def getMiniMapColour(self):
-        colours = self.app.theme.colours
-        if self.zoneOwner:
-            return colours.miniMapZoneOwnColour(self.orbOwner)
-        elif self.orbOwner:
-            return colours.miniMapOrbOwnColour(self.orbOwner)
-        else:
-            return colours.neutral_mn_bg
-        
