@@ -25,10 +25,6 @@ screenSize = 1024, 768
 fullScreen = True
 useAlpha = True
 
-# Until we have the limited sight range implemented, very high resolutions may be
-# used to cheat, so there is an option here to limit the valid resolutions.
-limitResolution = (1024, 768)
-
 maxNameLength = 20
 
 
