@@ -247,7 +247,7 @@ class DetailsInterface(framework.CompoundElement):
         self.currentChats.newMessage(allText,
                 self.app.theme.colours.chatColour(sender.team))
 
-    def sentOpenChat(self, team, text):
+    def sentPublicChat(self, team, text):
         self.currentChats.newMessage('Me (open): %s' % (text,),
                 self.app.theme.colours.chatColour(team))
 
@@ -255,7 +255,7 @@ class DetailsInterface(framework.CompoundElement):
         self.currentChats.newMessage('Me (to_%s): %s' % (nick, text),
                 self.app.theme.colours.chatColour(team))
 
-    def sentPublicChat(self, team, text):
+    def sentTeamChat(self, team, text):
         self.currentChats.newMessage('Me: %s' % (text,),
                 self.app.theme.colours.chatColour(team))
 
