@@ -51,12 +51,12 @@ from trosnoth.src.messages import (TaggingZoneMsg, ChatFromServerMsg, ChatMsg,
         CannotJoinMsg, AddPlayerMsg, UpdatePlayerStateMsg, AimPlayerAtMsg,
         RemovePlayerMsg, PlayerHasUpgradeMsg, PlayerStarsSpentMsg,
         DeleteUpgradeMsg, CannotBuyUpgradeMsg, ConnectionLostMsg,
-        NotifyUDPStatusMsg, ServerShutdownMsg)
+        NotifyUDPStatusMsg)
 
 from twisted.internet import defer, reactor
 
 class GameInterface(framework.CompoundElement, Component):
-    '''Interface for when we are connected to a server.'''
+    '''Interface for when we are connected to a game.'''
 
     controller = Plug()
     eventPlug = Plug()
@@ -65,6 +65,15 @@ class GameInterface(framework.CompoundElement, Component):
             onConnectionLost=None):
         super(GameInterface, self).__init__(app)
         Component.__init__(self)
+
+        self.onDisconnectRequest = Event()
+        if onDisconnectRequest is not None:
+            self.onDisconnectRequest.addListener(onDisconnectRequest)
+
+        self.onConnectionLost = Event()
+        if onConnectionLost is not None:
+            self.onConnectionLost.addListener(onConnectionLost)
+            
         self.world = world
 
         self.keyMapping = keyboard.KeyboardMapping(keymap.default_game_keys)
@@ -73,6 +82,8 @@ class GameInterface(framework.CompoundElement, Component):
         self.gameViewer = viewManager.GameViewer(self.app, self, world)
         if world.replay:
             self.gameMenu = ReplayMenu(self.app, world)
+            closeReplay = self.onDisconnectRequest.execute
+            self.gameMenu.onDisconnectRequest.addListener(closeReplay)
         else:
             self.gameMenu = GameMenu(self.app, self, world)
         self.detailsInterface = DetailsInterface(self.app, self)
@@ -97,20 +108,12 @@ class GameInterface(framework.CompoundElement, Component):
             self.elements.append(self.vcInterface)
             self.hideMenu()
 
-        self.onDisconnectRequest = Event()
-        if onDisconnectRequest is not None:
-            self.onDisconnectRequest.addListener(onDisconnectRequest)
-
-        self.onConnectionLost = Event()
-        if onConnectionLost is not None:
-            self.onConnectionLost.addListener(onConnectionLost)
 
     @handler(SetTeamNameMsg, eventPlug)
     @handler(UpdatePlayerStateMsg, eventPlug)
     @handler(AimPlayerAtMsg, eventPlug)
     @handler(SetGameModeMsg, eventPlug)
     @handler(PlayerUpdateMsg, eventPlug)
-    @handler(ServerShutdownMsg, eventPlug)
     def ignoreMessage(self, msg):
         pass
 
