@@ -20,7 +20,7 @@ from trosnoth.src.trosnothgui.ingame.dialogs import JoinGameDialog, JoiningDialo
 from trosnoth.src.gui.framework.dialogbox import DialogResult
 from trosnoth.src.gui.screenManager.windowManager import MultiWindowException
 
-from trosnoth.src.utils.getUserInfo import getName, writeName
+from trosnoth.src.utils.getUserInfo import writeName
 from trosnoth.src.trosnothgui.defines import maxNameLength
 
 class GameMenu(InGameMenu):
@@ -63,17 +63,14 @@ class GameMenu(InGameMenu):
 
             team = self.joinGameDialog.selectedTeam
             self.joiningInfo = nick, team
-            self.interface.netClient.join(
-                    nick,
-                    team
-            ).addCallback(self.joinComplete).addErrback(self.joinErrback)
             self.joiningScreen.show(nick)
+            self.interface.joinGame(nick, team).addCallback(self.joinComplete
+                    ).addErrback(self.joinErrback)
         
     def showMessage(self, text):
         self.joinGameDialog.cantJoinYet.setText(text)
 
     def cancelJoin(self, sender):
-        self.interface.netClient.cancelJoin(*self.joiningInfo)
         self.joiningScreen.Close()
         self.joinGameDialog.Show()
 
@@ -102,6 +99,8 @@ class GameMenu(InGameMenu):
         elif result[0] == 'wait':
             # Need to wait a few seconds before rejoining.
             self.showMessage('You need to wait ' + result[1] + ' seconds before rejoining.')
+        elif result[0] == 'timeout':
+            self.showMessage('Join timed out.')
         elif result[0] == 'error':
             # Python error.
             self.showMessage('Join failed: python error')
