@@ -16,16 +16,15 @@
 # 02110-1301, USA.
 
 import pygame
-import random
 
-from twisted.internet import reactor, task
 from trosnoth.src.gui.framework.elements import TextElement
 from trosnoth.src.gui.framework import clock, timer
-from trosnoth.src.gui.common import *
+from trosnoth.src.gui.common import (Area, FullScreenAttachedPoint, Location,
+        ScaledSize)
 import trosnoth.src.gui.framework.framework as framework
-from trosnoth.src.gui.fonts import font
 from trosnoth.src.model.universe_base import GameState
 from trosnoth.src.utils import logging
+from twisted.internet import task, reactor
 
 class GameTimer(framework.CompoundElement):
     def __init__(self, app, world):
@@ -45,11 +44,11 @@ class GameTimer(framework.CompoundElement):
                                       Location(FullScreenAttachedPoint(ScaledSize(0, -2), 'midtop'), 'midtop'),
                                       app.theme.colours.timerFontColour)
         self.elements = [self.notStarted]
+        self.running = False
 
         self.flashControl = task.LoopingCall(self.flash)
     
         self.gameTimer = None
-        self.gameOver = False
         self.timerAdjustLoop = None
         self.countingDown = None
         self.startedFlashing = False
@@ -63,22 +62,19 @@ class GameTimer(framework.CompoundElement):
         self.loop()
 
     def loop(self):
-        if self.world.gameState in (GameState.PreGame, GameState.Ended):
-            return
-
-##        # sync the clock every 10 seconds
-##        if self.world.gameState == GameState.InProgress:
-##            self.timerAdjustLoop = reactor.callLater(10, self.loop)
-      
-      
-        if self.gameTimer is None:
-            timeLeft = self.world.getTimeLeft()
-            self.gameStarted(timeLeft)
-                
+        self.timerAdjustLoop = reactor.callLater(10, self.loop)
         self.syncTimer()
 
+    def checkState(self):
+        if self.world.gameState != GameState.InProgress:
+            if self.running:
+                self.gameFinished()
+        elif not self.running:
+            self.gameStarted(self.world.getTimeLeft())
+
     def syncTimer(self):
-        if self.world.gameState in (GameState.PreGame, GameState.Ended):
+        self.checkState()
+        if self.gameTimer is None:
             return
         time = self.world.getTimeLeft()
         
@@ -122,6 +118,7 @@ class GameTimer(framework.CompoundElement):
             self.flashControl.stop()
 
     def gameStarted(self, time):
+        self.running = True
 
         if time > 0:
             self.gameTimer = timer.CountdownTimer(time, highest = "minutes")
@@ -140,13 +137,14 @@ class GameTimer(framework.CompoundElement):
         self.flashControl.start(self.flashFreq)
 
     def gameFinished(self):
+        self.running = False
         if self.timerAdjustLoop is not None:
             self.timerAdjustLoop.cancel()
             self.timerAdjustLoop = None
             self.gameTimer.pause()
-            self.gameOver = True
             self.flashControl.stop()
             self.gameClock.setColours(self.app.theme.colours.timerFontColour)
+            self.gameTimer = None
         self.elements = [self.notStarted]
 
     def _getRect(self):
@@ -154,6 +152,7 @@ class GameTimer(framework.CompoundElement):
 
 
     def draw(self, surface):     
+        self.checkState()
         timerBox = self._getRect()
         # Box background
         surface.fill(self.app.theme.colours.timerBackground, timerBox)
