@@ -18,13 +18,13 @@
 from trosnoth.src.gui.framework.elements import TextElement, TextButton
 from trosnoth.src.gui.framework import framework
 from trosnoth.src.gui.common import ScaledLocation
-from trosnoth.src.trosnothgui.pregame import colours
 from trosnoth.src.gui.common import *
 
 
 class ConnectingScreen(framework.CompoundElement):
     def __init__(self, app, serverName = 'server', onCancel=None):
         super(ConnectingScreen, self).__init__(app)
+        colours = app.theme.colours
 
         self.text = TextElement(self.app, 'Connecting to %s...' % serverName,
                 self.app.screenManager.fonts.bigMenuFont,
