@@ -38,27 +38,29 @@ class KeymapTab(Tab):
             self.onClose.addListener(onClose)
 
         # Break things up into categories
-        movement = ['left', 'right', 'jump', 'down']
-        menus =    ['menu']
+        movement = ['jump', 'down', 'left', 'right']
+        menus =    ['menu', 'more actions']
         actions =  ['respawn', 'buy upgrade',
                     'abandon', 'captain', 'team ready']
-        misc =     ['chat']
+        misc =     ['chat', 'follow']
         upgrades = ['turret', 'shield', 'minimap disruption', 'phase shift',
                     'grenade', 'ricochet']
-        display =  ['leaderboard', 'toggle interface']
+        display =  ['leaderboard', 'toggle interface', 'toggle terminal']
 
         actionNames = { 'abandon': 'Abandon upgrade',
                         'buy upgrade': 'Buy upgrade',
                         'captain': 'Become captain',
                         'chat': 'Chat',
                         'down': 'Drop down',
+                        'follow': 'Auto pan (replay)',
                         'grenade': 'Grenade',
                         'jump': 'Jump',
                         'leaderboard': 'Show leaderboard',
                         'left': 'Move left',
                         'menu': 'Main menu',
-                        'minimap disruption': 'Minimap Disruption',
-                        'phase shift': 'Phase Shift',
+                        'minimap disruption': 'Minimap disruption',
+                        'more actions': 'Advanced',
+                        'phase shift': 'Phase shift',
                         'respawn': 'Respawn',
                         'ricochet': 'Ricochet',
                         'right': 'Move right',
@@ -67,11 +69,12 @@ class KeymapTab(Tab):
                         'team ready': 'Team ready',
                         'timer': 'Show timer',
                         'toggle interface': 'Toggle HUD',
+                        'toggle terminal': 'Toggle terminal',
                         'turret': 'Turret',
                         'zone progress': 'Show zone bar'}
 
         # Organise the categories by column
-        self.layout = [ [movement, menus, misc], [actions], [upgrades, display] ]
+        self.layout = [ [movement, menus], [actions, display], [upgrades, misc] ]
 
         self.errorInfo = TextElement(self.app, '', self.font,
                                  ScaledLocation(512, 580, 'center'))
