@@ -171,14 +171,14 @@ class ServerDoesntExistMenu(framework.TabFriendlyCompoundElement):
             self.warnForRecording = False
         del json
 
-#        self.recordReplayBox = CheckBox(self.app, ScaledLocation(600, 520),
-#                                        text = 'Save Replay',
-#                                        font = app.screenManager.fonts.smallNoteFont,
-#                                        colour = colours.mainMenuColour,
-#                                        initValue = not self.warnForRecording,
-#                                        style='circle')
+        self.recordReplayBox = CheckBox(self.app, ScaledLocation(600, 520),
+                                        text = 'Record Game',
+                                        font = app.screenManager.fonts.smallNoteFont,
+                                        colour = colours.mainMenuColour,
+                                        initValue = not self.warnForRecording,
+                                        style='circle')
 
-#        self.recordReplayBox.onValueChanged.addListener(self.recordReplayButtonClicked)
+        self.recordReplayBox.onValueChanged.addListener(self.recordReplayButtonClicked)
         self.invisibleGameBox = CheckBox(self.app, ScaledLocation(800, 520),
                                            text = 'Invisible',
                                            font = app.screenManager.fonts.smallNoteFont,
@@ -200,7 +200,7 @@ class ServerDoesntExistMenu(framework.TabFriendlyCompoundElement):
         self.enableGameDuration(True)
 
         self.elements = self.text + self.input + \
-                        [#self.recordReplayBox,
+                        [self.recordReplayBox,
                          self.invisibleGameBox,
                          self.noLimitBox,
                          self.invalidInputText,
@@ -347,7 +347,7 @@ class ServerDoesntExistMenu(framework.TabFriendlyCompoundElement):
             return None
 
 
-        recordReplay = False#self.recordReplayBox.value
+        recordReplay = self.recordReplayBox.value
         invisible = self.invisibleGameBox.value
         width, height = radioChoice
 
